// This extension is a derived work of the Gnome Shell.
//
// Copyright (c) 2012 Norman L. Smith
//
// This extension is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This extension is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this extension; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

const Lang = imports.lang;

const Main = imports.ui.main;

const Gettext = imports.gettext.domain('nls1729-extensions');
const _ = Gettext.gettext;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;

const TEXT_KEY = 'activities-button-text';

const ActivitiesButtonText = new Lang.Class({
    Name: 'ActivitiesButtonText.ActivitiesButtonText',

    _init : function() {
        this._savedText = Main.panel._activitiesButton._label.get_text();
        this._settings = Convenience.getSettings();
        this._settings.connect('changed::'+TEXT_KEY, Lang.bind(this, this._setActivitiesButtonText));
        this._setActivitiesButtonText();
    },

    _setActivitiesButtonText: function() {
        let buttonText = this._settings.get_string(TEXT_KEY) || this._savedText;
        Main.panel._activitiesButton._label.set_text(buttonText);
    },

    destroy: function() {
        this._settings.run_dispose();
        this._settings = null;
    }
});

let activitiesButtonText;

function init(metadata) {
    Convenience.initTranslations();
}

function enable() {
     activitiesButtonText = new ActivitiesButtonText();
}

function disable() {
    Main.panel._activitiesButton._label.set_text(activitiesButtonText._savedText);
    activitiesButtonText.destroy();
    activitiesButtonText = null;
}
